@@ -50,7 +50,7 @@ def set_settings(ctx, instance=None):
 
     settings = None
 
-    _echo_enabled = ctx.invoked_subcommand not in ["get", None]
+    _echo_enabled = ctx.invoked_subcommand not in ["get", "inspect", None]
 
     if instance is not None:
         if ctx.invoked_subcommand in ["init"]:
@@ -819,7 +819,9 @@ INSPECT_FORMATS = list(builtin_dumpers.keys())
 
 @main.command()
 @click.option("--key", "-k", help="Filters result by key.")
-@click.option("--env", "-e", help="Filters result by environment.", default="")
+@click.option(
+    "--env", "-e", help="Filters result by environment.", default=None
+)
 @click.option(
     "--format",
     "-f",
@@ -828,13 +830,32 @@ INSPECT_FORMATS = list(builtin_dumpers.keys())
     type=click.Choice(INSPECT_FORMATS),
 )
 @click.option(
-    "--descending",
-    "-d",
-    help="Set history loading order to 'last-first'",
-    default=False,
+    "--old-first",
+    "new_first",
+    "-s",
+    help="Invert history sorting to 'old-first'",
+    default=True,
     is_flag=True,
 )
-def inspect(key, env, format, descending):  # pragma: no cover
+@click.option(
+    "--limit",
+    "history_limit",
+    "-n",
+    default=None,
+    type=int,
+    help="Limits how many history entries are shown.",
+)
+@click.option(
+    "--all",
+    "_all",
+    "-a",
+    default=False,
+    is_flag=True,
+    help="Show dynaconf internal settings?",
+)
+def inspect(
+    key, env, format, new_first, history_limit, _all
+):  # pragma: no cover
     """
     Inspect the loading history of the given settings instance.
 
@@ -843,10 +864,13 @@ def inspect(key, env, format, descending):  # pragma: no cover
     try:
         inspect_settings(
             settings,
-            key_dotted_path=key,
-            env=env,
-            output_format=format,
-            ascending_order=(not descending),
+            key=key,
+            env=env or None,
+            dumper=format,
+            new_first=new_first,
+            include_internal=_all,
+            history_limit=history_limit,
+            print_report=True,
         )
         click.echo()
     except (KeyNotFoundError, EnvNotFoundError, OutputFormatError) as err:
