@@ -16,6 +16,8 @@ from dynaconf.utils import deduplicate
 from dynaconf.utils import ensure_a_list
 from dynaconf.utils.boxing import DynaBox
 from dynaconf.utils.files import get_local_filename
+from dynaconf.utils.files import glob
+from dynaconf.utils.files import has_magic
 from dynaconf.utils.parse_conf import false_values
 
 if TYPE_CHECKING:
@@ -39,7 +41,7 @@ def default_loader(obj, defaults=None):
     for key in all_keys:
         if not obj.exists(key):
             value = defaults.get(key, default_settings_values.get(key))
-            obj.set(key, value)
+            obj.set(key, value, loader_identifier="default_settings")
 
     # start dotenv to get default env vars from there
     # check overrides in env vars
@@ -62,7 +64,12 @@ def default_loader(obj, defaults=None):
         )
 
         if env_value != "_not_found":
-            obj.set(key, env_value, tomlfy=True)
+            obj.set(
+                key,
+                env_value,
+                tomlfy=True,
+                loader_identifier="envvars_first_load",
+            )
 
 
 def execute_instance_hooks(
@@ -169,13 +176,25 @@ def _run_hook_function(
 
     # update obj settings
     if hook_dict:
+        identifier = f"{hook_func.__name__}@{hook_source}"
         merge = hook_dict.pop(
             "dynaconf_merge", hook_dict.pop("DYNACONF_MERGE", False)
         )
         if key and key in hook_dict:
-            obj.set(key, hook_dict[key], tomlfy=False, merge=merge)
+            obj.set(
+                key,
+                hook_dict[key],
+                tomlfy=False,
+                merge=merge,
+                loader_identifier=identifier,
+            )
         elif not key:
-            obj.update(hook_dict, tomlfy=False, merge=merge)
+            obj.update(
+                hook_dict,
+                tomlfy=False,
+                merge=merge,
+                loader_identifier=identifier,
+            )
 
     # add to registry
     obj._loaded_hooks[hook_source][hook_type] = hook_dict
@@ -213,10 +232,19 @@ def settings_loader(
     modules_names = []
     for item in files:
         item = str(item)  # Ensure str in case of LocalPath/Path is passed.
-        if item.endswith(ct.ALL_EXTENSIONS + (".py",)):
-            p_root = obj._root_path or (
-                os.path.dirname(found_files[0]) if found_files else None
-            )
+        p_root = obj._root_path or (
+            os.path.dirname(found_files[0]) if found_files else None
+        )
+        if has_magic(item):
+            # handle possible globs inside files list
+            # like ["path/*.yaml", "path/ABC?.yaml"]
+            globedfiles = glob(item, root_dir=p_root)
+            for globedfile in globedfiles:
+                # use object.find_file logic to handle skip files
+                found = obj.find_file(globedfile, project_root=p_root)
+                if found:
+                    found_files.append(found)
+        elif item.endswith(ct.ALL_EXTENSIONS + (".py",)):
             found = obj.find_file(item, project_root=p_root)
             if found:
                 found_files.append(found)
